@@ -45,15 +45,6 @@ class SettingsController extends Controller {
 		$this->settingsService = $settingsService;
 	}
 
-	/**
-	 * @NoAdminRequired
-	 */
-	public function get() {
-		return $this->generateResponse(function () {
-			return ['settings' => $this->settingsService->get()];
-		});
-	}
-
 	/**
 	 * @NoAdminRequired
 	 */
